@@ -23,7 +23,7 @@
 extern int dmarcf_mail_parse __P((unsigned char *, unsigned char **,
                                   unsigned char **));
 extern int dmarcf_mail_parse_multi __P((char *, unsigned char ***,
-                                       unsigned char ***));
+                                       unsigned char ***, unsigned int *));
 
 
 #endif /* ! _DMARCF_MAILPARSE_H_ */
